@@ -18,33 +18,35 @@
 #'
 #' album_palettes$evermore
 album_palettes <- lapply(list(
-  taylor_swift = c("#1D4737", "#1BAEC6", "#523d28", "#AD8562", "#E7DBCC"),
-  fearless     = c("#6B5E57", "#776456", "#976F34", "#CBA863", "#E1D4C2"),
+  taylor_swift = c("#1D4737", "#81A757", "#1BAEC6", "#523d28", "#E7DBCC"),
+  fearless     = c("#6E4823", "#976F34", "#CBA863", "#ECD59F", "#E1D4C2"),
   fearless_tv  = c("#624324", "#A47F45", "#CAA462", "#C5AA7C", "#EEDBA9"),
   speak_now    = c("#2E1924", "#6C3127", "#833C63", "#D1A0C7", "#F5E8E2"),
   red          = c("#201F39", "#A91E47", "#7E6358", "#B0A49A", "#DDD8C9"),
-  red_tv       = c("#592617", "#967862", "#B38468", "#C7C5B6", "#7C9694"),
+  red_tv       = c("#400303", "#731803", "#967862", "#B38468", "#C7C5B6"),
   `1989`       = c("#5D4E5D", "#846578", "#92573C", "#C6B69C", "#D8D8CF"),
   reputation   = c("#2C2C2C", "#515151", "#5B5B5B", "#6E6E6E", "#B9B9B9"),
-  lover        = c("#8C4F66", "#9C8083", "#847262", "#6098B6", "#EBBED3"),
+  lover        = c("#76BAE0", "#8C4F66", "#B8396B", "#EBBED3", "#FFF5CC"),
   folklore     = c("#3E3E3E", "#545454", "#5C5C5C", "#949494", "#EBEBEB"),
-  evermore     = c("#160E10", "#421E18", "#D37F55", "#85796D", "#E0D9D7")
+  evermore     = c("#160E10", "#421E18", "#D37F55", "#85796D", "#E0D9D7"),
+  midnights    = c("#121D27", "#5A658B", "#6F86A2", "#85A7BA", "#AA9EB6")
 ), color_palette)
 
 #' @rdname album_palettes
 #' @export
 album_compare <- color_palette(
   c(taylor_swift = "#1BAEC6",
-    fearless     = "#976F34",
+    fearless     = "#CBA863",
     fearless_tv  = "#624324",
     speak_now    = "#833C63",
     red          = "#A91E47",
-    red_tv       = "#592617",
+    red_tv       = "#731803",
     `1989`       = "#846578",
     reputation   = "#2C2C2C",
     lover        = "#EBBED3",
     folklore     = "#949494",
-    evermore     = "#421E18")
+    evermore     = "#421E18",
+    midnights    = "#AA9EB6")
 )
 
 
@@ -81,7 +83,7 @@ album_compare <- color_palette(
 #'   geom_col()
 album_levels <- c("Taylor Swift", "Fearless", "Fearless (Taylor's Version)",
                   "Speak Now", "Red", "Red (Taylor's Version)", "1989",
-                  "reputation", "Lover", "folklore", "evermore")
+                  "reputation", "Lover", "folklore", "evermore", "Midnights")
 
 
 # Scale functions --------------------------------------------------------------
@@ -115,7 +117,8 @@ taylor_col <- function(n, alpha = 1, begin = 0, end = 1, direction = 1,
                    reputation   = taylor::album_palettes[["reputation"]],
                    lover        = taylor::album_palettes[["lover"]],
                    folklore     = taylor::album_palettes[["folklore"]],
-                   evermore     = taylor::album_palettes[["evermore"]], {
+                   evermore     = taylor::album_palettes[["evermore"]],
+                   midnights    = taylor::album_palettes[["midnights"]], {
                      rlang::warn(paste0("Album '", album, "' does not exist. ",
                                         "Defaulting to 'Lover'."))
                      taylor::album_palettes[["lover"]]
